# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0btypes.proto\x12\x0bproto_types\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x91\x02\n\tEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x05\x65xtra\x18\t \x03(\x0b\x32!.proto_types.EventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\rTimingInfoMsg\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"V\n\x0cNodeRelation\x12\x10\n\x08\x64\x61tabase\x18\n \x01(\t\x12\x0e\n\x06schema\x18\x0b \x01(\t\x12\r\n\x05\x61lias\x18\x0c \x01(\t\x12\x15\n\rrelation_name\x18\r \x01(\t\"\x91\x02\n\x08NodeInfo\x12\x11\n\tnode_path\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x11\n\tunique_id\x18\x03 \x01(\t\x12\x15\n\rresource_type\x18\x04 \x01(\t\x12\x14\n\x0cmaterialized\x18\x05 \x01(\t\x12\x13\n\x0bnode_status\x18\x06 \x01(\t\x12\x17\n\x0fnode_started_at\x18\x07 \x01(\t\x12\x18\n\x10node_finished_at\x18\x08 \x01(\t\x12%\n\x04meta\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\rnode_relation\x18\n \x01(\x0b\x32\x19.proto_types.NodeRelation\"\xd1\x01\n\x0cRunResultMsg\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\x0btiming_info\x18\x03 \x03(\x0b\x32\x1a.proto_types.TimingInfoMsg\x12\x0e\n\x06thread\x18\x04 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x31\n\x10\x61\x64\x61pter_response\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"G\n\x0fReferenceKeyMsg\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\"6\n\x0eGenericMessage\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\"9\n\x11MainReportVersion\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x13\n\x0blog_version\x18\x02 \x01(\x05\"j\n\x14MainReportVersionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.MainReportVersion\"r\n\x0eMainReportArgs\x12\x33\n\x04\x61rgs\x18\x01 \x03(\x0b\x32%.proto_types.MainReportArgs.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x11MainReportArgsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainReportArgs\"+\n\x15MainTrackingUserState\x12\x12\n\nuser_state\x18\x01 \x01(\t\"r\n\x18MainTrackingUserStateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainTrackingUserState\"5\n\x0fMergedFromState\x12\x12\n\nnum_merged\x18\x01 \x01(\x05\x12\x0e\n\x06sample\x18\x02 \x03(\t\"f\n\x12MergedFromStateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.MergedFromState\"A\n\x14MissingProfileTarget\x12\x14\n\x0cprofile_name\x18\x01 \x01(\t\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\"p\n\x17MissingProfileTargetMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MissingProfileTarget\"(\n\x11InvalidOptionYAML\x12\x13\n\x0boption_name\x18\x01 \x01(\t\"j\n\x14InvalidOptionYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.InvalidOptionYAML\"!\n\x12LogDbtProjectError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"l\n\x15LogDbtProjectErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProjectError\"3\n\x12LogDbtProfileError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08profiles\x18\x02 \x03(\t\"l\n\x15LogDbtProfileErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDbtProfileError\"!\n\x12StarterProjectPath\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"l\n\x15StarterProjectPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StarterProjectPath\"$\n\x15\x43onfigFolderDirectory\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"r\n\x18\x43onfigFolderDirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConfigFolderDirectory\"\'\n\x14NoSampleProfileFound\x12\x0f\n\x07\x61\x64\x61pter\x18\x01 \x01(\t\"p\n\x17NoSampleProfileFoundMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NoSampleProfileFound\"6\n\x18ProfileWrittenWithSample\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"x\n\x1bProfileWrittenWithSampleMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProfileWrittenWithSample\"B\n$ProfileWrittenWithTargetTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x90\x01\n\'ProfileWrittenWithTargetTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.ProfileWrittenWithTargetTemplateYAML\"C\n%ProfileWrittenWithProjectTemplateYAML\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\x92\x01\n(ProfileWrittenWithProjectTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.ProfileWrittenWithProjectTemplateYAML\"\x12\n\x10SettingUpProfile\"h\n\x13SettingUpProfileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SettingUpProfile\"\x1c\n\x1aInvalidProfileTemplateYAML\"|\n\x1dInvalidProfileTemplateYAMLMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.InvalidProfileTemplateYAML\"(\n\x18ProjectNameAlreadyExists\x12\x0c\n\x04name\x18\x01 \x01(\t\"x\n\x1bProjectNameAlreadyExistsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ProjectNameAlreadyExists\"K\n\x0eProjectCreated\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x02 \x01(\t\x12\x11\n\tslack_url\x18\x03 \x01(\t\"d\n\x11ProjectCreatedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ProjectCreated\"@\n\x1aPackageRedirectDeprecation\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"|\n\x1dPackageRedirectDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.PackageRedirectDeprecation\"\x1f\n\x1dPackageInstallPathDeprecation\"\x82\x01\n PackageInstallPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.PackageInstallPathDeprecation\"H\n\x1b\x43onfigSourcePathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"~\n\x1e\x43onfigSourcePathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigSourcePathDeprecation\"F\n\x19\x43onfigDataPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\x12\x10\n\x08\x65xp_path\x18\x02 \x01(\t\"z\n\x1c\x43onfigDataPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConfigDataPathDeprecation\"?\n\x19\x41\x64\x61pterDeprecationWarning\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"z\n\x1c\x41\x64\x61pterDeprecationWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.AdapterDeprecationWarning\".\n\x17MetricAttributesRenamed\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\"v\n\x1aMetricAttributesRenamedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.MetricAttributesRenamed\"+\n\x17\x45xposureNameDeprecation\x12\x10\n\x08\x65xposure\x18\x01 \x01(\t\"v\n\x1a\x45xposureNameDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.ExposureNameDeprecation\"^\n\x13InternalDeprecation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x18\n\x10suggested_action\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"n\n\x16InternalDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.InternalDeprecation\"@\n\x1a\x45nvironmentVariableRenamed\x12\x10\n\x08old_name\x18\x01 \x01(\t\x12\x10\n\x08new_name\x18\x02 \x01(\t\"|\n\x1d\x45nvironmentVariableRenamedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.EnvironmentVariableRenamed\"3\n\x18\x43onfigLogPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"x\n\x1b\x43onfigLogPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.ConfigLogPathDeprecation\"6\n\x1b\x43onfigTargetPathDeprecation\x12\x17\n\x0f\x64\x65precated_path\x18\x01 \x01(\t\"~\n\x1e\x43onfigTargetPathDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConfigTargetPathDeprecation\"!\n\x1f\x43ollectFreshnessReturnSignature\"\x86\x01\n\"CollectFreshnessReturnSignatureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.CollectFreshnessReturnSignature\"\x87\x01\n\x11\x41\x64\x61pterEventDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"j\n\x14\x41\x64\x61pterEventDebugMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterEventDebug\"\x86\x01\n\x10\x41\x64\x61pterEventInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"h\n\x13\x41\x64\x61pterEventInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.AdapterEventInfo\"\x89\x01\n\x13\x41\x64\x61pterEventWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\"n\n\x16\x41\x64\x61pterEventWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.AdapterEventWarning\"\x99\x01\n\x11\x41\x64\x61pterEventError\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x62\x61se_msg\x18\x03 \x01(\t\x12(\n\x04\x61rgs\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x10\n\x08\x65xc_info\x18\x05 \x01(\t\"j\n\x14\x41\x64\x61pterEventErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterEventError\"_\n\rNewConnection\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"b\n\x10NewConnectionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NewConnection\"=\n\x10\x43onnectionReused\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x16\n\x0eorig_conn_name\x18\x02 \x01(\t\"h\n\x13\x43onnectionReusedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConnectionReused\"0\n\x1b\x43onnectionLeftOpenInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"~\n\x1e\x43onnectionLeftOpenInCleanupMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.ConnectionLeftOpenInCleanup\".\n\x19\x43onnectionClosedInCleanup\x12\x11\n\tconn_name\x18\x01 \x01(\t\"z\n\x1c\x43onnectionClosedInCleanupMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.ConnectionClosedInCleanup\"_\n\x0eRollbackFailed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"d\n\x11RollbackFailedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RollbackFailed\"O\n\x10\x43onnectionClosed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"h\n\x13\x43onnectionClosedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConnectionClosed\"Q\n\x12\x43onnectionLeftOpen\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"l\n\x15\x43onnectionLeftOpenMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ConnectionLeftOpen\"G\n\x08Rollback\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"X\n\x0bRollbackMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.Rollback\"@\n\tCacheMiss\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\"Z\n\x0c\x43\x61\x63heMissMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.CacheMiss\"b\n\rListRelations\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12/\n\trelations\x18\x03 \x03(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"b\n\x10ListRelationsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.ListRelations\"`\n\x0e\x43onnectionUsed\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_type\x18\x02 \x01(\t\x12\x11\n\tconn_name\x18\x03 \x01(\t\"d\n\x11\x43onnectionUsedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.ConnectionUsed\"T\n\x08SQLQuery\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\x12\x0b\n\x03sql\x18\x03 \x01(\t\"X\n\x0bSQLQueryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.SQLQuery\"[\n\x0eSQLQueryStatus\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x03 \x01(\x02\"d\n\x11SQLQueryStatusMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.SQLQueryStatus\"H\n\tSQLCommit\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tconn_name\x18\x02 \x01(\t\"Z\n\x0cSQLCommitMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.SQLCommit\"a\n\rColTypeChange\x12\x11\n\torig_type\x18\x01 \x01(\t\x12\x10\n\x08new_type\x18\x02 \x01(\t\x12+\n\x05table\x18\x03 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"b\n\x10\x43olTypeChangeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.ColTypeChange\"@\n\x0eSchemaCreation\x12.\n\x08relation\x18\x01 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"d\n\x11SchemaCreationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.SchemaCreation\"<\n\nSchemaDrop\x12.\n\x08relation\x18\x01 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"\\\n\rSchemaDropMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SchemaDrop\"\xde\x01\n\x0b\x43\x61\x63heAction\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12-\n\x07ref_key\x18\x02 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12/\n\tref_key_2\x18\x03 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12/\n\tref_key_3\x18\x04 \x01(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\x12.\n\x08ref_list\x18\x05 \x03(\x0b\x32\x1c.proto_types.ReferenceKeyMsg\"^\n\x0e\x43\x61\x63heActionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.CacheAction\"\x98\x01\n\x0e\x43\x61\x63heDumpGraph\x12\x33\n\x04\x64ump\x18\x01 \x03(\x0b\x32%.proto_types.CacheDumpGraph.DumpEntry\x12\x14\n\x0c\x62\x65\x66ore_after\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x1a+\n\tDumpEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x11\x43\x61\x63heDumpGraphMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CacheDumpGraph\"B\n\x11\x41\x64\x61pterRegistered\x12\x14\n\x0c\x61\x64\x61pter_name\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x61pter_version\x18\x02 \x01(\t\"j\n\x14\x41\x64\x61pterRegisteredMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.AdapterRegistered\"!\n\x12\x41\x64\x61pterImportError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"l\n\x15\x41\x64\x61pterImportErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.AdapterImportError\"#\n\x0fPluginLoadError\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"f\n\x12PluginLoadErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.PluginLoadError\"Z\n\x14NewConnectionOpening\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x18\n\x10\x63onnection_state\x18\x02 \x01(\t\"p\n\x17NewConnectionOpeningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.NewConnectionOpening\"8\n\rCodeExecution\x12\x11\n\tconn_name\x18\x01 \x01(\t\x12\x14\n\x0c\x63ode_content\x18\x02 \x01(\t\"b\n\x10\x43odeExecutionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.CodeExecution\"6\n\x13\x43odeExecutionStatus\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07\x65lapsed\x18\x02 \x01(\x02\"n\n\x16\x43odeExecutionStatusMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.CodeExecutionStatus\"%\n\x16\x43\x61talogGenerationError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"t\n\x19\x43\x61talogGenerationErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.CatalogGenerationError\"-\n\x13WriteCatalogFailure\x12\x16\n\x0enum_exceptions\x18\x01 \x01(\x05\"n\n\x16WriteCatalogFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.WriteCatalogFailure\"\x1e\n\x0e\x43\x61talogWritten\x12\x0c\n\x04path\x18\x01 \x01(\t\"d\n\x11\x43\x61talogWrittenMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CatalogWritten\"\x14\n\x12\x43\x61nnotGenerateDocs\"l\n\x15\x43\x61nnotGenerateDocsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.CannotGenerateDocs\"\x11\n\x0f\x42uildingCatalog\"f\n\x12\x42uildingCatalogMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.BuildingCatalog\"-\n\x18\x44\x61tabaseErrorRunningHook\x12\x11\n\thook_type\x18\x01 \x01(\t\"x\n\x1b\x44\x61tabaseErrorRunningHookMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DatabaseErrorRunningHook\"4\n\x0cHooksRunning\x12\x11\n\tnum_hooks\x18\x01 \x01(\x05\x12\x11\n\thook_type\x18\x02 \x01(\t\"`\n\x0fHooksRunningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.HooksRunning\"T\n\x14\x46inishedRunningStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\x12\x11\n\texecution\x18\x02 \x01(\t\x12\x16\n\x0e\x65xecution_time\x18\x03 \x01(\x02\"p\n\x17\x46inishedRunningStatsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.FinishedRunningStats\"<\n\x15\x43onstraintNotEnforced\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"r\n\x18\x43onstraintNotEnforcedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ConstraintNotEnforced\"=\n\x16\x43onstraintNotSupported\x12\x12\n\nconstraint\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\"t\n\x19\x43onstraintNotSupportedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.ConstraintNotSupported\"7\n\x12InputFileDiffError\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x0f\n\x07\x66ile_id\x18\x02 \x01(\t\"l\n\x15InputFileDiffErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InputFileDiffError\"?\n\x14InvalidValueForField\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\t\"p\n\x17InvalidValueForFieldMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.InvalidValueForField\"Q\n\x11ValidationWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x12\n\nfield_name\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\"j\n\x14ValidationWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ValidationWarning\"!\n\x11ParsePerfInfoPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"j\n\x14ParsePerfInfoPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.ParsePerfInfoPath\"1\n!PartialParsingErrorProcessingFile\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\"\x8a\x01\n$PartialParsingErrorProcessingFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.PartialParsingErrorProcessingFile\"\x86\x01\n\x13PartialParsingError\x12?\n\x08\x65xc_info\x18\x01 \x03(\x0b\x32-.proto_types.PartialParsingError.ExcInfoEntry\x1a.\n\x0c\x45xcInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x16PartialParsingErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.PartialParsingError\"\x1b\n\x19PartialParsingSkipParsing\"z\n\x1cPartialParsingSkipParsingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.PartialParsingSkipParsing\"&\n\x14UnableToPartialParse\x12\x0e\n\x06reason\x18\x01 \x01(\t\"p\n\x17UnableToPartialParseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.UnableToPartialParse\"f\n\x12StateCheckVarsHash\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x0c\n\x04vars\x18\x02 \x01(\t\x12\x0f\n\x07profile\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\"l\n\x15StateCheckVarsHashMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.StateCheckVarsHash\"\x1a\n\x18PartialParsingNotEnabled\"x\n\x1bPartialParsingNotEnabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.PartialParsingNotEnabled\"C\n\x14ParsedFileLoadFailed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"p\n\x17ParsedFileLoadFailedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.ParsedFileLoadFailed\"H\n\x15PartialParsingEnabled\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x05\x12\r\n\x05\x61\x64\x64\x65\x64\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hanged\x18\x03 \x01(\x05\"r\n\x18PartialParsingEnabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.PartialParsingEnabled\"8\n\x12PartialParsingFile\x12\x0f\n\x07\x66ile_id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\"l\n\x15PartialParsingFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.PartialParsingFile\"\xaf\x01\n\x1fInvalidDisabledTargetInTestNode\x12\x1b\n\x13resource_type_title\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1a\n\x12original_file_path\x18\x03 \x01(\t\x12\x13\n\x0btarget_kind\x18\x04 \x01(\t\x12\x13\n\x0btarget_name\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\"\x86\x01\n\"InvalidDisabledTargetInTestNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.InvalidDisabledTargetInTestNode\"7\n\x18UnusedResourceConfigPath\x12\x1b\n\x13unused_config_paths\x18\x01 \x03(\t\"x\n\x1bUnusedResourceConfigPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.UnusedResourceConfigPath\"3\n\rSeedIncreased\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x10SeedIncreasedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.SeedIncreased\">\n\x18SeedExceedsLimitSamePath\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"x\n\x1bSeedExceedsLimitSamePathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.SeedExceedsLimitSamePath\"D\n\x1eSeedExceedsLimitAndPathChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x84\x01\n!SeedExceedsLimitAndPathChangedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.SeedExceedsLimitAndPathChanged\"\\\n\x1fSeedExceedsLimitChecksumChanged\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rchecksum_name\x18\x03 \x01(\t\"\x86\x01\n\"SeedExceedsLimitChecksumChangedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.SeedExceedsLimitChecksumChanged\"%\n\x0cUnusedTables\x12\x15\n\runused_tables\x18\x01 \x03(\t\"`\n\x0fUnusedTablesMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.UnusedTables\"\x87\x01\n\x17WrongResourceSchemaFile\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x1c\n\x14plural_resource_type\x18\x03 \x01(\t\x12\x10\n\x08yaml_key\x18\x04 \x01(\t\x12\x11\n\tfile_path\x18\x05 \x01(\t\"v\n\x1aWrongResourceSchemaFileMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.WrongResourceSchemaFile\"K\n\x10NoNodeForYamlKey\x12\x12\n\npatch_name\x18\x01 \x01(\t\x12\x10\n\x08yaml_key\x18\x02 \x01(\t\x12\x11\n\tfile_path\x18\x03 \x01(\t\"h\n\x13NoNodeForYamlKeyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.NoNodeForYamlKey\"+\n\x15MacroNotFoundForPatch\x12\x12\n\npatch_name\x18\x01 \x01(\t\"r\n\x18MacroNotFoundForPatchMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MacroNotFoundForPatch\"\xb8\x01\n\x16NodeNotFoundOrDisabled\x12\x1a\n\x12original_file_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x1b\n\x13resource_type_title\x18\x03 \x01(\t\x12\x13\n\x0btarget_name\x18\x04 \x01(\t\x12\x13\n\x0btarget_kind\x18\x05 \x01(\t\x12\x16\n\x0etarget_package\x18\x06 \x01(\t\x12\x10\n\x08\x64isabled\x18\x07 \x01(\t\"t\n\x19NodeNotFoundOrDisabledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.NodeNotFoundOrDisabled\"H\n\x0fJinjaLogWarning\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"f\n\x12JinjaLogWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.JinjaLogWarning\"E\n\x0cJinjaLogInfo\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"`\n\x0fJinjaLogInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.JinjaLogInfo\"F\n\rJinjaLogDebug\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03msg\x18\x02 \x01(\t\"b\n\x10JinjaLogDebugMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.JinjaLogDebug\"\xae\x01\n\x1eUnpinnedRefNewVersionAvailable\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rref_node_name\x18\x02 \x01(\t\x12\x18\n\x10ref_node_package\x18\x03 \x01(\t\x12\x18\n\x10ref_node_version\x18\x04 \x01(\t\x12\x17\n\x0fref_max_version\x18\x05 \x01(\t\"\x84\x01\n!UnpinnedRefNewVersionAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.UnpinnedRefNewVersionAvailable\"V\n\x0f\x44\x65precatedModel\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65precation_date\x18\x03 \x01(\t\"f\n\x12\x44\x65precatedModelMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DeprecatedModel\"\xc6\x01\n\x1cUpcomingReferenceDeprecation\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"\x80\x01\n\x1fUpcomingReferenceDeprecationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).proto_types.UpcomingReferenceDeprecation\"\xbd\x01\n\x13\x44\x65precatedReference\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x19\n\x11ref_model_package\x18\x02 \x01(\t\x12\x16\n\x0eref_model_name\x18\x03 \x01(\t\x12\x19\n\x11ref_model_version\x18\x04 \x01(\t\x12 \n\x18ref_model_latest_version\x18\x05 \x01(\t\x12\"\n\x1aref_model_deprecation_date\x18\x06 \x01(\t\"n\n\x16\x44\x65precatedReferenceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DeprecatedReference\"<\n$UnsupportedConstraintMaterialization\x12\x14\n\x0cmaterialized\x18\x01 \x01(\t\"\x90\x01\n\'UnsupportedConstraintMaterializationMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.proto_types.UnsupportedConstraintMaterialization\"/\n\x1dGitSparseCheckoutSubdirectory\x12\x0e\n\x06subdir\x18\x01 \x01(\t\"\x82\x01\n GitSparseCheckoutSubdirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.GitSparseCheckoutSubdirectory\"/\n\x1bGitProgressCheckoutRevision\x12\x10\n\x08revision\x18\x01 \x01(\t\"~\n\x1eGitProgressCheckoutRevisionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.GitProgressCheckoutRevision\"4\n%GitProgressUpdatingExistingDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x92\x01\n(GitProgressUpdatingExistingDependencyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.proto_types.GitProgressUpdatingExistingDependency\".\n\x1fGitProgressPullingNewDependency\x12\x0b\n\x03\x64ir\x18\x01 \x01(\t\"\x86\x01\n\"GitProgressPullingNewDependencyMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressPullingNewDependency\"\x1d\n\x0eGitNothingToDo\x12\x0b\n\x03sha\x18\x01 \x01(\t\"d\n\x11GitNothingToDoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.GitNothingToDo\"E\n\x1fGitProgressUpdatedCheckoutRange\x12\x11\n\tstart_sha\x18\x01 \x01(\t\x12\x0f\n\x07\x65nd_sha\x18\x02 \x01(\t\"\x86\x01\n\"GitProgressUpdatedCheckoutRangeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.GitProgressUpdatedCheckoutRange\"*\n\x17GitProgressCheckedOutAt\x12\x0f\n\x07\x65nd_sha\x18\x01 \x01(\t\"v\n\x1aGitProgressCheckedOutAtMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.GitProgressCheckedOutAt\")\n\x1aRegistryProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"|\n\x1dRegistryProgressGETRequestMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.RegistryProgressGETRequest\"=\n\x1bRegistryProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"~\n\x1eRegistryProgressGETResponseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RegistryProgressGETResponse\"_\n\x1dSelectorReportInvalidSelector\x12\x17\n\x0fvalid_selectors\x18\x01 \x01(\t\x12\x13\n\x0bspec_method\x18\x02 \x01(\t\x12\x10\n\x08raw_spec\x18\x03 \x01(\t\"\x82\x01\n SelectorReportInvalidSelectorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.SelectorReportInvalidSelector\"\x15\n\x13\x44\x65psNoPackagesFound\"n\n\x16\x44\x65psNoPackagesFoundMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsNoPackagesFound\"/\n\x17\x44\x65psStartPackageInstall\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\"v\n\x1a\x44\x65psStartPackageInstallMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsStartPackageInstall\"\'\n\x0f\x44\x65psInstallInfo\x12\x14\n\x0cversion_name\x18\x01 \x01(\t\"f\n\x12\x44\x65psInstallInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DepsInstallInfo\"-\n\x13\x44\x65psUpdateAvailable\x12\x16\n\x0eversion_latest\x18\x01 \x01(\t\"n\n\x16\x44\x65psUpdateAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.DepsUpdateAvailable\"\x0e\n\x0c\x44\x65psUpToDate\"`\n\x0f\x44\x65psUpToDateMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUpToDate\",\n\x14\x44\x65psListSubdirectory\x12\x14\n\x0csubdirectory\x18\x01 \x01(\t\"p\n\x17\x44\x65psListSubdirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.DepsListSubdirectory\".\n\x1a\x44\x65psNotifyUpdatesAvailable\x12\x10\n\x08packages\x18\x01 \x03(\t\"|\n\x1d\x44\x65psNotifyUpdatesAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.DepsNotifyUpdatesAvailable\"1\n\x11RetryExternalCall\x12\x0f\n\x07\x61ttempt\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"j\n\x14RetryExternalCallMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.RetryExternalCall\"#\n\x14RecordRetryException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x17RecordRetryExceptionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.RecordRetryException\".\n\x1fRegistryIndexProgressGETRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\"\x86\x01\n\"RegistryIndexProgressGETRequestMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryIndexProgressGETRequest\"B\n RegistryIndexProgressGETResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x11\n\tresp_code\x18\x02 \x01(\x05\"\x88\x01\n#RegistryIndexProgressGETResponseMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12;\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32-.proto_types.RegistryIndexProgressGETResponse\"2\n\x1eRegistryResponseUnexpectedType\x12\x10\n\x08response\x18\x01 \x01(\t\"\x84\x01\n!RegistryResponseUnexpectedTypeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseUnexpectedType\"2\n\x1eRegistryResponseMissingTopKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x84\x01\n!RegistryResponseMissingTopKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.proto_types.RegistryResponseMissingTopKeys\"5\n!RegistryResponseMissingNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x8a\x01\n$RegistryResponseMissingNestedKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12<\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32..proto_types.RegistryResponseMissingNestedKeys\"3\n\x1fRegistryResponseExtraNestedKeys\x12\x10\n\x08response\x18\x01 \x01(\t\"\x86\x01\n\"RegistryResponseExtraNestedKeysMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12:\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32,.proto_types.RegistryResponseExtraNestedKeys\"(\n\x18\x44\x65psSetDownloadDirectory\x12\x0c\n\x04path\x18\x01 \x01(\t\"x\n\x1b\x44\x65psSetDownloadDirectoryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsSetDownloadDirectory\"-\n\x0c\x44\x65psUnpinned\x12\x10\n\x08revision\x18\x01 \x01(\t\x12\x0b\n\x03git\x18\x02 \x01(\t\"`\n\x0f\x44\x65psUnpinnedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.DepsUnpinned\"/\n\x1bNoNodesForSelectionCriteria\x12\x10\n\x08spec_raw\x18\x01 \x01(\t\"~\n\x1eNoNodesForSelectionCriteriaMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.NoNodesForSelectionCriteria\"*\n\x1bRunningOperationCaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"~\n\x1eRunningOperationCaughtErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.RunningOperationCaughtError\"\x11\n\x0f\x43ompileComplete\"f\n\x12\x43ompileCompleteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.CompileComplete\"\x18\n\x16\x46reshnessCheckComplete\"t\n\x19\x46reshnessCheckCompleteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.FreshnessCheckComplete\"\x1c\n\nSeedHeader\x12\x0e\n\x06header\x18\x01 \x01(\t\"\\\n\rSeedHeaderMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.SeedHeader\"3\n\x12SQLRunnerException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x02 \x01(\t\"l\n\x15SQLRunnerExceptionMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SQLRunnerException\"\xa8\x01\n\rLogTestResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\x12\n\nnum_models\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x14\n\x0cnum_failures\x18\x07 \x01(\x05\"b\n\x10LogTestResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogTestResult\"k\n\x0cLogStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"`\n\x0fLogStartLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.LogStartLine\"\x95\x01\n\x0eLogModelResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"d\n\x11LogModelResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogModelResult\"\xfa\x01\n\x11LogSnapshotResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x34\n\x03\x63\x66g\x18\x07 \x03(\x0b\x32\'.proto_types.LogSnapshotResult.CfgEntry\x1a*\n\x08\x43\x66gEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x14LogSnapshotResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12,\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.proto_types.LogSnapshotResult\"\xb9\x01\n\rLogSeedResult\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x16\n\x0eresult_message\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\x12\x0e\n\x06schema\x18\x07 \x01(\t\x12\x10\n\x08relation\x18\x08 \x01(\t\"b\n\x10LogSeedResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogSeedResult\"\xad\x01\n\x12LogFreshnessResult\x12\x0e\n\x06status\x18\x01 \x01(\t\x12(\n\tnode_info\x18\x02 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x05 \x01(\x02\x12\x13\n\x0bsource_name\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\"l\n\x15LogFreshnessResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogFreshnessResult\"\"\n\rLogCancelLine\x12\x11\n\tconn_name\x18\x01 \x01(\t\"b\n\x10LogCancelLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.LogCancelLine\"\x1f\n\x0f\x44\x65\x66\x61ultSelector\x12\x0c\n\x04name\x18\x01 \x01(\t\"f\n\x12\x44\x65\x66\x61ultSelectorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DefaultSelector\"5\n\tNodeStart\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"Z\n\x0cNodeStartMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.NodeStart\"g\n\x0cNodeFinished\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12-\n\nrun_result\x18\x02 \x01(\x0b\x32\x19.proto_types.RunResultMsg\"`\n\x0fNodeFinishedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.NodeFinished\"+\n\x1bQueryCancelationUnsupported\x12\x0c\n\x04type\x18\x01 \x01(\t\"~\n\x1eQueryCancelationUnsupportedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x36\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32(.proto_types.QueryCancelationUnsupported\"O\n\x0f\x43oncurrencyLine\x12\x13\n\x0bnum_threads\x18\x01 \x01(\x05\x12\x13\n\x0btarget_name\x18\x02 \x01(\t\x12\x12\n\nnode_count\x18\x03 \x01(\x05\"f\n\x12\x43oncurrencyLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ConcurrencyLine\"E\n\x19WritingInjectedSQLForNode\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"z\n\x1cWritingInjectedSQLForNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.WritingInjectedSQLForNode\"9\n\rNodeCompiling\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"b\n\x10NodeCompilingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeCompiling\"9\n\rNodeExecuting\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\"b\n\x10NodeExecutingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12(\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1a.proto_types.NodeExecuting\"m\n\x10LogHookStartLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"h\n\x13LogHookStartLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.LogHookStartLine\"\x93\x01\n\x0eLogHookEndLine\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x11\n\tstatement\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05index\x18\x04 \x01(\x05\x12\r\n\x05total\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xecution_time\x18\x06 \x01(\x02\"d\n\x11LogHookEndLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.LogHookEndLine\"\x93\x01\n\x0fSkippingDetails\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tnode_name\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x05\x12\r\n\x05total\x18\x06 \x01(\x05\"f\n\x12SkippingDetailsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SkippingDetails\"\r\n\x0bNothingToDo\"^\n\x0eNothingToDoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.NothingToDo\",\n\x1dRunningOperationUncaughtError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x82\x01\n RunningOperationUncaughtErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x38\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32*.proto_types.RunningOperationUncaughtError\"\x93\x01\n\x0c\x45ndRunResult\x12*\n\x07results\x18\x01 \x03(\x0b\x32\x19.proto_types.RunResultMsg\x12\x14\n\x0c\x65lapsed_time\x18\x02 \x01(\x02\x12\x30\n\x0cgenerated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07success\x18\x04 \x01(\x08\"`\n\x0f\x45ndRunResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.EndRunResult\"\x11\n\x0fNoNodesSelected\"f\n\x12NoNodesSelectedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.NoNodesSelected\"w\n\x10\x43ommandCompleted\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x30\n\x0c\x63ompleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x65lapsed\x18\x04 \x01(\x02\"h\n\x13\x43ommandCompletedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.CommandCompleted\"k\n\x08ShowNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0f\n\x07preview\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"X\n\x0bShowNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12#\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x15.proto_types.ShowNode\"p\n\x0c\x43ompiledNode\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x10\n\x08\x63ompiled\x18\x02 \x01(\t\x12\x11\n\tis_inline\x18\x03 \x01(\x08\x12\x15\n\routput_format\x18\x04 \x01(\t\x12\x11\n\tunique_id\x18\x05 \x01(\t\"`\n\x0f\x43ompiledNodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.CompiledNode\"b\n\x17\x43\x61tchableExceptionOnRun\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"v\n\x1a\x43\x61tchableExceptionOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.CatchableExceptionOnRun\"5\n\x12InternalErrorOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\"l\n\x15InternalErrorOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.InternalErrorOnRun\"K\n\x15GenericExceptionOnRun\x12\x12\n\nbuild_path\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\"r\n\x18GenericExceptionOnRunMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.GenericExceptionOnRun\"N\n\x1aNodeConnectionReleaseError\x12\x11\n\tnode_name\x18\x01 \x01(\t\x12\x0b\n\x03\x65xc\x18\x02 \x01(\t\x12\x10\n\x08\x65xc_info\x18\x03 \x01(\t\"|\n\x1dNodeConnectionReleaseErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.proto_types.NodeConnectionReleaseError\"\x1f\n\nFoundStats\x12\x11\n\tstat_line\x18\x01 \x01(\t\"\\\n\rFoundStatsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.FoundStats\"\x17\n\x15MainKeyboardInterrupt\"r\n\x18MainKeyboardInterruptMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.MainKeyboardInterrupt\"#\n\x14MainEncounteredError\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"p\n\x17MainEncounteredErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.MainEncounteredError\"%\n\x0eMainStackTrace\x12\x13\n\x0bstack_trace\x18\x01 \x01(\t\"d\n\x11MainStackTraceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.MainStackTrace\"@\n\x13SystemCouldNotWrite\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\"n\n\x16SystemCouldNotWriteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.SystemCouldNotWrite\"!\n\x12SystemExecutingCmd\x12\x0b\n\x03\x63md\x18\x01 \x03(\t\"l\n\x15SystemExecutingCmdMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.SystemExecutingCmd\"\x1c\n\x0cSystemStdOut\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"`\n\x0fSystemStdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SystemStdOut\"\x1c\n\x0cSystemStdErr\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"`\n\x0fSystemStdErrMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SystemStdErr\",\n\x16SystemReportReturnCode\x12\x12\n\nreturncode\x18\x01 \x01(\x05\"t\n\x19SystemReportReturnCodeMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.proto_types.SystemReportReturnCode\"p\n\x13TimingInfoCollected\x12(\n\tnode_info\x18\x01 \x01(\x0b\x32\x15.proto_types.NodeInfo\x12/\n\x0btiming_info\x18\x02 \x01(\x0b\x32\x1a.proto_types.TimingInfoMsg\"n\n\x16TimingInfoCollectedMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.TimingInfoCollected\"&\n\x12LogDebugStackTrace\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"l\n\x15LogDebugStackTraceMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.LogDebugStackTrace\"\x1e\n\x0e\x43heckCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"d\n\x11\x43heckCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.CheckCleanPath\" \n\x10\x43onfirmCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"h\n\x13\x43onfirmCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.ConfirmCleanPath\"\"\n\x12ProtectedCleanPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"l\n\x15ProtectedCleanPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.ProtectedCleanPath\"\x14\n\x12\x46inishedCleanPaths\"l\n\x15\x46inishedCleanPathsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FinishedCleanPaths\"5\n\x0bOpenCommand\x12\x10\n\x08open_cmd\x18\x01 \x01(\t\x12\x14\n\x0cprofiles_dir\x18\x02 \x01(\t\"^\n\x0eOpenCommandMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.OpenCommand\"\x19\n\nFormatting\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\\\n\rFormattingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.Formatting\"0\n\x0fServingDocsPort\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"f\n\x12ServingDocsPortMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.ServingDocsPort\"%\n\x15ServingDocsAccessInfo\x12\x0c\n\x04port\x18\x01 \x01(\t\"r\n\x18ServingDocsAccessInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x30\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\".proto_types.ServingDocsAccessInfo\"\x15\n\x13ServingDocsExitInfo\"n\n\x16ServingDocsExitInfoMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.ServingDocsExitInfo\"J\n\x10RunResultWarning\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"h\n\x13RunResultWarningMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultWarning\"J\n\x10RunResultFailure\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\"h\n\x13RunResultFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.RunResultFailure\"k\n\tStatsLine\x12\x30\n\x05stats\x18\x01 \x03(\x0b\x32!.proto_types.StatsLine.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"Z\n\x0cStatsLineMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.proto_types.StatsLine\"\x1d\n\x0eRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"d\n\x11RunResultErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.RunResultError\")\n\x17RunResultErrorNoMessage\x12\x0e\n\x06status\x18\x01 \x01(\t\"v\n\x1aRunResultErrorNoMessageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultErrorNoMessage\"\x1f\n\x0fSQLCompiledPath\x12\x0c\n\x04path\x18\x01 \x01(\t\"f\n\x12SQLCompiledPathMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.SQLCompiledPath\"-\n\x14\x43heckNodeTestFailure\x12\x15\n\rrelation_name\x18\x01 \x01(\t\"p\n\x17\x43heckNodeTestFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12/\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32!.proto_types.CheckNodeTestFailure\"\"\n\x13\x46irstRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"n\n\x16\x46irstRunResultErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.FirstRunResultError\"\'\n\x18\x41\x66terFirstRunResultError\x12\x0b\n\x03msg\x18\x01 \x01(\t\"x\n\x1b\x41\x66terFirstRunResultErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.AfterFirstRunResultError\"W\n\x0f\x45ndOfRunSummary\x12\x12\n\nnum_errors\x18\x01 \x01(\x05\x12\x14\n\x0cnum_warnings\x18\x02 \x01(\x05\x12\x1a\n\x12keyboard_interrupt\x18\x03 \x01(\x08\"f\n\x12\x45ndOfRunSummaryMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.EndOfRunSummary\"U\n\x13LogSkipBecauseError\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x10\n\x08relation\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"n\n\x16LogSkipBecauseErrorMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32 .proto_types.LogSkipBecauseError\"\x14\n\x12\x45nsureGitInstalled\"l\n\x15\x45nsureGitInstalledMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.EnsureGitInstalled\"\x1a\n\x18\x44\x65psCreatingLocalSymlink\"x\n\x1b\x44\x65psCreatingLocalSymlinkMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x33\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32%.proto_types.DepsCreatingLocalSymlink\"\x19\n\x17\x44\x65psSymlinkNotAvailable\"v\n\x1a\x44\x65psSymlinkNotAvailableMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.DepsSymlinkNotAvailable\"\x11\n\x0f\x44isableTracking\"f\n\x12\x44isableTrackingMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.proto_types.DisableTracking\"\x1e\n\x0cSendingEvent\x12\x0e\n\x06kwargs\x18\x01 \x01(\t\"`\n\x0fSendingEventMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\'\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x19.proto_types.SendingEvent\"\x12\n\x10SendEventFailure\"h\n\x13SendEventFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.proto_types.SendEventFailure\"\r\n\x0b\x46lushEvents\"^\n\x0e\x46lushEventsMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.FlushEvents\"\x14\n\x12\x46lushEventsFailure\"l\n\x15\x46lushEventsFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12-\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1f.proto_types.FlushEventsFailure\"-\n\x19TrackingInitializeFailure\x12\x10\n\x08\x65xc_info\x18\x01 \x01(\t\"z\n\x1cTrackingInitializeFailureMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x34\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32&.proto_types.TrackingInitializeFailure\"&\n\x17RunResultWarningMessage\x12\x0b\n\x03msg\x18\x01 \x01(\t\"v\n\x1aRunResultWarningMessageMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x32\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32$.proto_types.RunResultWarningMessage\"\x1a\n\x0b\x44\x65\x62ugCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"^\n\x0e\x44\x65\x62ugCmdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12&\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x18.proto_types.DebugCmdOut\"\x1d\n\x0e\x44\x65\x62ugCmdResult\x12\x0b\n\x03msg\x18\x01 \x01(\t\"d\n\x11\x44\x65\x62ugCmdResultMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12)\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.proto_types.DebugCmdResult\"\x19\n\nListCmdOut\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\\\n\rListCmdOutMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.proto_types.ListCmdOut\"\x13\n\x04Note\x12\x0b\n\x03msg\x18\x01 \x01(\t\"P\n\x07NoteMsg\x12$\n\x04info\x18\x01 \x01(\x0b\x32\x16.proto_types.EventInfo\x12\x1f\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x11.proto_types.Noteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EVENTINFO_EXTRAENTRY._options = None
  _EVENTINFO_EXTRAENTRY._serialized_options = b'8\001'
  _MAINREPORTARGS_ARGSENTRY._options = None
  _MAINREPORTARGS_ARGSENTRY._serialized_options = b'8\001'
  _CACHEDUMPGRAPH_DUMPENTRY._options = None
  _CACHEDUMPGRAPH_DUMPENTRY._serialized_options = b'8\001'
  _PARTIALPARSINGERROR_EXCINFOENTRY._options = None
  _PARTIALPARSINGERROR_EXCINFOENTRY._serialized_options = b'8\001'
  _LOGSNAPSHOTRESULT_CFGENTRY._options = None
  _LOGSNAPSHOTRESULT_CFGENTRY._serialized_options = b'8\001'
  _STATSLINE_STATSENTRY._options = None
  _STATSLINE_STATSENTRY._serialized_options = b'8\001'
  _globals['_EVENTINFO']._serialized_start=92
  _globals['_EVENTINFO']._serialized_end=365
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_start=321
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_end=365
  _globals['_TIMINGINFOMSG']._serialized_start=367
  _globals['_TIMINGINFOMSG']._serialized_end=494
  _globals['_NODERELATION']._serialized_start=496
  _globals['_NODERELATION']._serialized_end=582
  _globals['_NODEINFO']._serialized_start=585
  _globals['_NODEINFO']._serialized_end=858
  _globals['_RUNRESULTMSG']._serialized_start=861
  _globals['_RUNRESULTMSG']._serialized_end=1070
  _globals['_REFERENCEKEYMSG']._serialized_start=1072
  _globals['_REFERENCEKEYMSG']._serialized_end=1143
  _globals['_GENERICMESSAGE']._serialized_start=1145
  _globals['_GENERICMESSAGE']._serialized_end=1199
  _globals['_MAINREPORTVERSION']._serialized_start=1201
  _globals['_MAINREPORTVERSION']._serialized_end=1258
  _globals['_MAINREPORTVERSIONMSG']._serialized_start=1260
  _globals['_MAINREPORTVERSIONMSG']._serialized_end=1366
  _globals['_MAINREPORTARGS']._serialized_start=1368
  _globals['_MAINREPORTARGS']._serialized_end=1482
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_start=1439
  _globals['_MAINREPORTARGS_ARGSENTRY']._serialized_end=1482
  _globals['_MAINREPORTARGSMSG']._serialized_start=1484
  _globals['_MAINREPORTARGSMSG']._serialized_end=1584
  _globals['_MAINTRACKINGUSERSTATE']._serialized_start=1586
  _globals['_MAINTRACKINGUSERSTATE']._serialized_end=1629
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_start=1631
  _globals['_MAINTRACKINGUSERSTATEMSG']._serialized_end=1745
  _globals['_MERGEDFROMSTATE']._serialized_start=1747
  _globals['_MERGEDFROMSTATE']._serialized_end=1800
  _globals['_MERGEDFROMSTATEMSG']._serialized_start=1802
  _globals['_MERGEDFROMSTATEMSG']._serialized_end=1904
  _globals['_MISSINGPROFILETARGET']._serialized_start=1906
  _globals['_MISSINGPROFILETARGET']._serialized_end=1971
  _globals['_MISSINGPROFILETARGETMSG']._serialized_start=1973
  _globals['_MISSINGPROFILETARGETMSG']._serialized_end=2085
  _globals['_INVALIDOPTIONYAML']._serialized_start=2087
  _globals['_INVALIDOPTIONYAML']._serialized_end=2127
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_start=2129
  _globals['_INVALIDOPTIONYAMLMSG']._serialized_end=2235
  _globals['_LOGDBTPROJECTERROR']._serialized_start=2237
  _globals['_LOGDBTPROJECTERROR']._serialized_end=2270
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_start=2272
  _globals['_LOGDBTPROJECTERRORMSG']._serialized_end=2380
  _globals['_LOGDBTPROFILEERROR']._serialized_start=2382
  _globals['_LOGDBTPROFILEERROR']._serialized_end=2433
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_start=2435
  _globals['_LOGDBTPROFILEERRORMSG']._serialized_end=2543
  _globals['_STARTERPROJECTPATH']._serialized_start=2545
  _globals['_STARTERPROJECTPATH']._serialized_end=2578
  _globals['_STARTERPROJECTPATHMSG']._serialized_start=2580
  _globals['_STARTERPROJECTPATHMSG']._serialized_end=2688
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_start=2690
  _globals['_CONFIGFOLDERDIRECTORY']._serialized_end=2726
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_start=2728
  _globals['_CONFIGFOLDERDIRECTORYMSG']._serialized_end=2842
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_start=2844
  _globals['_NOSAMPLEPROFILEFOUND']._serialized_end=2883
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_start=2885
  _globals['_NOSAMPLEPROFILEFOUNDMSG']._serialized_end=2997
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_start=2999
  _globals['_PROFILEWRITTENWITHSAMPLE']._serialized_end=3053
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_start=3055
  _globals['_PROFILEWRITTENWITHSAMPLEMSG']._serialized_end=3175
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_start=3177
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAML']._serialized_end=3243
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_start=3246
  _globals['_PROFILEWRITTENWITHTARGETTEMPLATEYAMLMSG']._serialized_end=3390
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_start=3392
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAML']._serialized_end=3459
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_start=3462
  _globals['_PROFILEWRITTENWITHPROJECTTEMPLATEYAMLMSG']._serialized_end=3608
  _globals['_SETTINGUPPROFILE']._serialized_start=3610
  _globals['_SETTINGUPPROFILE']._serialized_end=3628
  _globals['_SETTINGUPPROFILEMSG']._serialized_start=3630
  _globals['_SETTINGUPPROFILEMSG']._serialized_end=3734
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_start=3736
  _globals['_INVALIDPROFILETEMPLATEYAML']._serialized_end=3764
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_start=3766
  _globals['_INVALIDPROFILETEMPLATEYAMLMSG']._serialized_end=3890
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_start=3892
  _globals['_PROJECTNAMEALREADYEXISTS']._serialized_end=3932
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_start=3934
  _globals['_PROJECTNAMEALREADYEXISTSMSG']._serialized_end=4054
  _globals['_PROJECTCREATED']._serialized_start=4056
  _globals['_PROJECTCREATED']._serialized_end=4131
  _globals['_PROJECTCREATEDMSG']._serialized_start=4133
  _globals['_PROJECTCREATEDMSG']._serialized_end=4233
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_start=4235
  _globals['_PACKAGEREDIRECTDEPRECATION']._serialized_end=4299
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_start=4301
  _globals['_PACKAGEREDIRECTDEPRECATIONMSG']._serialized_end=4425
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_start=4427
  _globals['_PACKAGEINSTALLPATHDEPRECATION']._serialized_end=4458
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_start=4461
  _globals['_PACKAGEINSTALLPATHDEPRECATIONMSG']._serialized_end=4591
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_start=4593
  _globals['_CONFIGSOURCEPATHDEPRECATION']._serialized_end=4665
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_start=4667
  _globals['_CONFIGSOURCEPATHDEPRECATIONMSG']._serialized_end=4793
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_start=4795
  _globals['_CONFIGDATAPATHDEPRECATION']._serialized_end=4865
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_start=4867
  _globals['_CONFIGDATAPATHDEPRECATIONMSG']._serialized_end=4989
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_start=4991
  _globals['_ADAPTERDEPRECATIONWARNING']._serialized_end=5054
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_start=5056
  _globals['_ADAPTERDEPRECATIONWARNINGMSG']._serialized_end=5178
  _globals['_METRICATTRIBUTESRENAMED']._serialized_start=5180
  _globals['_METRICATTRIBUTESRENAMED']._serialized_end=5226
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_start=5228
  _globals['_METRICATTRIBUTESRENAMEDMSG']._serialized_end=5346
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_start=5348
  _globals['_EXPOSURENAMEDEPRECATION']._serialized_end=5391
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_start=5393
  _globals['_EXPOSURENAMEDEPRECATIONMSG']._serialized_end=5511
  _globals['_INTERNALDEPRECATION']._serialized_start=5513
  _globals['_INTERNALDEPRECATION']._serialized_end=5607
  _globals['_INTERNALDEPRECATIONMSG']._serialized_start=5609
  _globals['_INTERNALDEPRECATIONMSG']._serialized_end=5719
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_start=5721
  _globals['_ENVIRONMENTVARIABLERENAMED']._serialized_end=5785
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_start=5787
  _globals['_ENVIRONMENTVARIABLERENAMEDMSG']._serialized_end=5911
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_start=5913
  _globals['_CONFIGLOGPATHDEPRECATION']._serialized_end=5964
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_start=5966
  _globals['_CONFIGLOGPATHDEPRECATIONMSG']._serialized_end=6086
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_start=6088
  _globals['_CONFIGTARGETPATHDEPRECATION']._serialized_end=6142
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_start=6144
  _globals['_CONFIGTARGETPATHDEPRECATIONMSG']._serialized_end=6270
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_start=6272
  _globals['_COLLECTFRESHNESSRETURNSIGNATURE']._serialized_end=6305
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_start=6308
  _globals['_COLLECTFRESHNESSRETURNSIGNATUREMSG']._serialized_end=6442
  _globals['_ADAPTEREVENTDEBUG']._serialized_start=6445
  _globals['_ADAPTEREVENTDEBUG']._serialized_end=6580
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_start=6582
  _globals['_ADAPTEREVENTDEBUGMSG']._serialized_end=6688
  _globals['_ADAPTEREVENTINFO']._serialized_start=6691
  _globals['_ADAPTEREVENTINFO']._serialized_end=6825
  _globals['_ADAPTEREVENTINFOMSG']._serialized_start=6827
  _globals['_ADAPTEREVENTINFOMSG']._serialized_end=6931
  _globals['_ADAPTEREVENTWARNING']._serialized_start=6934
  _globals['_ADAPTEREVENTWARNING']._serialized_end=7071
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_start=7073
  _globals['_ADAPTEREVENTWARNINGMSG']._serialized_end=7183
  _globals['_ADAPTEREVENTERROR']._serialized_start=7186
  _globals['_ADAPTEREVENTERROR']._serialized_end=7339
  _globals['_ADAPTEREVENTERRORMSG']._serialized_start=7341
  _globals['_ADAPTEREVENTERRORMSG']._serialized_end=7447
  _globals['_NEWCONNECTION']._serialized_start=7449
  _globals['_NEWCONNECTION']._serialized_end=7544
  _globals['_NEWCONNECTIONMSG']._serialized_start=7546
  _globals['_NEWCONNECTIONMSG']._serialized_end=7644
  _globals['_CONNECTIONREUSED']._serialized_start=7646
  _globals['_CONNECTIONREUSED']._serialized_end=7707
  _globals['_CONNECTIONREUSEDMSG']._serialized_start=7709
  _globals['_CONNECTIONREUSEDMSG']._serialized_end=7813
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_start=7815
  _globals['_CONNECTIONLEFTOPENINCLEANUP']._serialized_end=7863
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_start=7865
  _globals['_CONNECTIONLEFTOPENINCLEANUPMSG']._serialized_end=7991
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_start=7993
  _globals['_CONNECTIONCLOSEDINCLEANUP']._serialized_end=8039
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_start=8041
  _globals['_CONNECTIONCLOSEDINCLEANUPMSG']._serialized_end=8163
  _globals['_ROLLBACKFAILED']._serialized_start=8165
  _globals['_ROLLBACKFAILED']._serialized_end=8260
  _globals['_ROLLBACKFAILEDMSG']._serialized_start=8262
  _globals['_ROLLBACKFAILEDMSG']._serialized_end=8362
  _globals['_CONNECTIONCLOSED']._serialized_start=8364
  _globals['_CONNECTIONCLOSED']._serialized_end=8443
  _globals['_CONNECTIONCLOSEDMSG']._serialized_start=8445
  _globals['_CONNECTIONCLOSEDMSG']._serialized_end=8549
  _globals['_CONNECTIONLEFTOPEN']._serialized_start=8551
  _globals['_CONNECTIONLEFTOPEN']._serialized_end=8632
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_start=8634
  _globals['_CONNECTIONLEFTOPENMSG']._serialized_end=8742
  _globals['_ROLLBACK']._serialized_start=8744
  _globals['_ROLLBACK']._serialized_end=8815
  _globals['_ROLLBACKMSG']._serialized_start=8817
  _globals['_ROLLBACKMSG']._serialized_end=8905
  _globals['_CACHEMISS']._serialized_start=8907
  _globals['_CACHEMISS']._serialized_end=8971
  _globals['_CACHEMISSMSG']._serialized_start=8973
  _globals['_CACHEMISSMSG']._serialized_end=9063
  _globals['_LISTRELATIONS']._serialized_start=9065
  _globals['_LISTRELATIONS']._serialized_end=9163
  _globals['_LISTRELATIONSMSG']._serialized_start=9165
  _globals['_LISTRELATIONSMSG']._serialized_end=9263
  _globals['_CONNECTIONUSED']._serialized_start=9265
  _globals['_CONNECTIONUSED']._serialized_end=9361
  _globals['_CONNECTIONUSEDMSG']._serialized_start=9363
  _globals['_CONNECTIONUSEDMSG']._serialized_end=9463
  _globals['_SQLQUERY']._serialized_start=9465
  _globals['_SQLQUERY']._serialized_end=9549
  _globals['_SQLQUERYMSG']._serialized_start=9551
  _globals['_SQLQUERYMSG']._serialized_end=9639
  _globals['_SQLQUERYSTATUS']._serialized_start=9641
  _globals['_SQLQUERYSTATUS']._serialized_end=9732
  _globals['_SQLQUERYSTATUSMSG']._serialized_start=9734
  _globals['_SQLQUERYSTATUSMSG']._serialized_end=9834
  _globals['_SQLCOMMIT']._serialized_start=9836
  _globals['_SQLCOMMIT']._serialized_end=9908
  _globals['_SQLCOMMITMSG']._serialized_start=9910
  _globals['_SQLCOMMITMSG']._serialized_end=10000
  _globals['_COLTYPECHANGE']._serialized_start=10002
  _globals['_COLTYPECHANGE']._serialized_end=10099
  _globals['_COLTYPECHANGEMSG']._serialized_start=10101
  _globals['_COLTYPECHANGEMSG']._serialized_end=10199
  _globals['_SCHEMACREATION']._serialized_start=10201
  _globals['_SCHEMACREATION']._serialized_end=10265
  _globals['_SCHEMACREATIONMSG']._serialized_start=10267
  _globals['_SCHEMACREATIONMSG']._serialized_end=10367
  _globals['_SCHEMADROP']._serialized_start=10369
  _globals['_SCHEMADROP']._serialized_end=10429
  _globals['_SCHEMADROPMSG']._serialized_start=10431
  _globals['_SCHEMADROPMSG']._serialized_end=10523
  _globals['_CACHEACTION']._serialized_start=10526
  _globals['_CACHEACTION']._serialized_end=10748
  _globals['_CACHEACTIONMSG']._serialized_start=10750
  _globals['_CACHEACTIONMSG']._serialized_end=10844
  _globals['_CACHEDUMPGRAPH']._serialized_start=10847
  _globals['_CACHEDUMPGRAPH']._serialized_end=10999
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_start=10956
  _globals['_CACHEDUMPGRAPH_DUMPENTRY']._serialized_end=10999
  _globals['_CACHEDUMPGRAPHMSG']._serialized_start=11001
  _globals['_CACHEDUMPGRAPHMSG']._serialized_end=11101
  _globals['_ADAPTERREGISTERED']._serialized_start=11103
  _globals['_ADAPTERREGISTERED']._serialized_end=11169
  _globals['_ADAPTERREGISTEREDMSG']._serialized_start=11171
  _globals['_ADAPTERREGISTEREDMSG']._serialized_end=11277
  _globals['_ADAPTERIMPORTERROR']._serialized_start=11279
  _globals['_ADAPTERIMPORTERROR']._serialized_end=11312
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_start=11314
  _globals['_ADAPTERIMPORTERRORMSG']._serialized_end=11422
  _globals['_PLUGINLOADERROR']._serialized_start=11424
  _globals['_PLUGINLOADERROR']._serialized_end=11459
  _globals['_PLUGINLOADERRORMSG']._serialized_start=11461
  _globals['_PLUGINLOADERRORMSG']._serialized_end=11563
  _globals['_NEWCONNECTIONOPENING']._serialized_start=11565
  _globals['_NEWCONNECTIONOPENING']._serialized_end=11655
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_start=11657
  _globals['_NEWCONNECTIONOPENINGMSG']._serialized_end=11769
  _globals['_CODEEXECUTION']._serialized_start=11771
  _globals['_CODEEXECUTION']._serialized_end=11827
  _globals['_CODEEXECUTIONMSG']._serialized_start=11829
  _globals['_CODEEXECUTIONMSG']._serialized_end=11927
  _globals['_CODEEXECUTIONSTATUS']._serialized_start=11929
  _globals['_CODEEXECUTIONSTATUS']._serialized_end=11983
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_start=11985
  _globals['_CODEEXECUTIONSTATUSMSG']._serialized_end=12095
  _globals['_CATALOGGENERATIONERROR']._serialized_start=12097
  _globals['_CATALOGGENERATIONERROR']._serialized_end=12134
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_start=12136
  _globals['_CATALOGGENERATIONERRORMSG']._serialized_end=12252
  _globals['_WRITECATALOGFAILURE']._serialized_start=12254
  _globals['_WRITECATALOGFAILURE']._serialized_end=12299
  _globals['_WRITECATALOGFAILUREMSG']._serialized_start=12301
  _globals['_WRITECATALOGFAILUREMSG']._serialized_end=12411
  _globals['_CATALOGWRITTEN']._serialized_start=12413
  _globals['_CATALOGWRITTEN']._serialized_end=12443
  _globals['_CATALOGWRITTENMSG']._serialized_start=12445
  _globals['_CATALOGWRITTENMSG']._serialized_end=12545
  _globals['_CANNOTGENERATEDOCS']._serialized_start=12547
  _globals['_CANNOTGENERATEDOCS']._serialized_end=12567
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_start=12569
  _globals['_CANNOTGENERATEDOCSMSG']._serialized_end=12677
  _globals['_BUILDINGCATALOG']._serialized_start=12679
  _globals['_BUILDINGCATALOG']._serialized_end=12696
  _globals['_BUILDINGCATALOGMSG']._serialized_start=12698
  _globals['_BUILDINGCATALOGMSG']._serialized_end=12800
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_start=12802
  _globals['_DATABASEERRORRUNNINGHOOK']._serialized_end=12847
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_start=12849
  _globals['_DATABASEERRORRUNNINGHOOKMSG']._serialized_end=12969
  _globals['_HOOKSRUNNING']._serialized_start=12971
  _globals['_HOOKSRUNNING']._serialized_end=13023
  _globals['_HOOKSRUNNINGMSG']._serialized_start=13025
  _globals['_HOOKSRUNNINGMSG']._serialized_end=13121
  _globals['_FINISHEDRUNNINGSTATS']._serialized_start=13123
  _globals['_FINISHEDRUNNINGSTATS']._serialized_end=13207
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_start=13209
  _globals['_FINISHEDRUNNINGSTATSMSG']._serialized_end=13321
  _globals['_CONSTRAINTNOTENFORCED']._serialized_start=13323
  _globals['_CONSTRAINTNOTENFORCED']._serialized_end=13383
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_start=13385
  _globals['_CONSTRAINTNOTENFORCEDMSG']._serialized_end=13499
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_start=13501
  _globals['_CONSTRAINTNOTSUPPORTED']._serialized_end=13562
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_start=13564
  _globals['_CONSTRAINTNOTSUPPORTEDMSG']._serialized_end=13680
  _globals['_INPUTFILEDIFFERROR']._serialized_start=13682
  _globals['_INPUTFILEDIFFERROR']._serialized_end=13737
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_start=13739
  _globals['_INPUTFILEDIFFERRORMSG']._serialized_end=13847
  _globals['_INVALIDVALUEFORFIELD']._serialized_start=13849
  _globals['_INVALIDVALUEFORFIELD']._serialized_end=13912
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_start=13914
  _globals['_INVALIDVALUEFORFIELDMSG']._serialized_end=14026
  _globals['_VALIDATIONWARNING']._serialized_start=14028
  _globals['_VALIDATIONWARNING']._serialized_end=14109
  _globals['_VALIDATIONWARNINGMSG']._serialized_start=14111
  _globals['_VALIDATIONWARNINGMSG']._serialized_end=14217
  _globals['_PARSEPERFINFOPATH']._serialized_start=14219
  _globals['_PARSEPERFINFOPATH']._serialized_end=14252
  _globals['_PARSEPERFINFOPATHMSG']._serialized_start=14254
  _globals['_PARSEPERFINFOPATHMSG']._serialized_end=14360
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_start=14362
  _globals['_PARTIALPARSINGERRORPROCESSINGFILE']._serialized_end=14411
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_start=14414
  _globals['_PARTIALPARSINGERRORPROCESSINGFILEMSG']._serialized_end=14552
  _globals['_PARTIALPARSINGERROR']._serialized_start=14555
  _globals['_PARTIALPARSINGERROR']._serialized_end=14689
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_start=14643
  _globals['_PARTIALPARSINGERROR_EXCINFOENTRY']._serialized_end=14689
  _globals['_PARTIALPARSINGERRORMSG']._serialized_start=14691
  _globals['_PARTIALPARSINGERRORMSG']._serialized_end=14801
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_start=14803
  _globals['_PARTIALPARSINGSKIPPARSING']._serialized_end=14830
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_start=14832
  _globals['_PARTIALPARSINGSKIPPARSINGMSG']._serialized_end=14954
  _globals['_UNABLETOPARTIALPARSE']._serialized_start=14956
  _globals['_UNABLETOPARTIALPARSE']._serialized_end=14994
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_start=14996
  _globals['_UNABLETOPARTIALPARSEMSG']._serialized_end=15108
  _globals['_STATECHECKVARSHASH']._serialized_start=15110
  _globals['_STATECHECKVARSHASH']._serialized_end=15212
  _globals['_STATECHECKVARSHASHMSG']._serialized_start=15214
  _globals['_STATECHECKVARSHASHMSG']._serialized_end=15322
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_start=15324
  _globals['_PARTIALPARSINGNOTENABLED']._serialized_end=15350
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_start=15352
  _globals['_PARTIALPARSINGNOTENABLEDMSG']._serialized_end=15472
  _globals['_PARSEDFILELOADFAILED']._serialized_start=15474
  _globals['_PARSEDFILELOADFAILED']._serialized_end=15541
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_start=15543
  _globals['_PARSEDFILELOADFAILEDMSG']._serialized_end=15655
  _globals['_PARTIALPARSINGENABLED']._serialized_start=15657
  _globals['_PARTIALPARSINGENABLED']._serialized_end=15729
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_start=15731
  _globals['_PARTIALPARSINGENABLEDMSG']._serialized_end=15845
  _globals['_PARTIALPARSINGFILE']._serialized_start=15847
  _globals['_PARTIALPARSINGFILE']._serialized_end=15903
  _globals['_PARTIALPARSINGFILEMSG']._serialized_start=15905
  _globals['_PARTIALPARSINGFILEMSG']._serialized_end=16013
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_start=16016
  _globals['_INVALIDDISABLEDTARGETINTESTNODE']._serialized_end=16191
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_start=16194
  _globals['_INVALIDDISABLEDTARGETINTESTNODEMSG']._serialized_end=16328
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_start=16330
  _globals['_UNUSEDRESOURCECONFIGPATH']._serialized_end=16385
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_start=16387
  _globals['_UNUSEDRESOURCECONFIGPATHMSG']._serialized_end=16507
  _globals['_SEEDINCREASED']._serialized_start=16509
  _globals['_SEEDINCREASED']._serialized_end=16560
  _globals['_SEEDINCREASEDMSG']._serialized_start=16562
  _globals['_SEEDINCREASEDMSG']._serialized_end=16660
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_start=16662
  _globals['_SEEDEXCEEDSLIMITSAMEPATH']._serialized_end=16724
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_start=16726
  _globals['_SEEDEXCEEDSLIMITSAMEPATHMSG']._serialized_end=16846
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_start=16848
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGED']._serialized_end=16916
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_start=16919
  _globals['_SEEDEXCEEDSLIMITANDPATHCHANGEDMSG']._serialized_end=17051
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_start=17053
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGED']._serialized_end=17145
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_start=17148
  _globals['_SEEDEXCEEDSLIMITCHECKSUMCHANGEDMSG']._serialized_end=17282
  _globals['_UNUSEDTABLES']._serialized_start=17284
  _globals['_UNUSEDTABLES']._serialized_end=17321
  _globals['_UNUSEDTABLESMSG']._serialized_start=17323
  _globals['_UNUSEDTABLESMSG']._serialized_end=17419
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_start=17422
  _globals['_WRONGRESOURCESCHEMAFILE']._serialized_end=17557
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_start=17559
  _globals['_WRONGRESOURCESCHEMAFILEMSG']._serialized_end=17677
  _globals['_NONODEFORYAMLKEY']._serialized_start=17679
  _globals['_NONODEFORYAMLKEY']._serialized_end=17754
  _globals['_NONODEFORYAMLKEYMSG']._serialized_start=17756
  _globals['_NONODEFORYAMLKEYMSG']._serialized_end=17860
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_start=17862
  _globals['_MACRONOTFOUNDFORPATCH']._serialized_end=17905
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_start=17907
  _globals['_MACRONOTFOUNDFORPATCHMSG']._serialized_end=18021
  _globals['_NODENOTFOUNDORDISABLED']._serialized_start=18024
  _globals['_NODENOTFOUNDORDISABLED']._serialized_end=18208
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_start=18210
  _globals['_NODENOTFOUNDORDISABLEDMSG']._serialized_end=18326
  _globals['_JINJALOGWARNING']._serialized_start=18328
  _globals['_JINJALOGWARNING']._serialized_end=18400
  _globals['_JINJALOGWARNINGMSG']._serialized_start=18402
  _globals['_JINJALOGWARNINGMSG']._serialized_end=18504
  _globals['_JINJALOGINFO']._serialized_start=18506
  _globals['_JINJALOGINFO']._serialized_end=18575
  _globals['_JINJALOGINFOMSG']._serialized_start=18577
  _globals['_JINJALOGINFOMSG']._serialized_end=18673
  _globals['_JINJALOGDEBUG']._serialized_start=18675
  _globals['_JINJALOGDEBUG']._serialized_end=18745
  _globals['_JINJALOGDEBUGMSG']._serialized_start=18747
  _globals['_JINJALOGDEBUGMSG']._serialized_end=18845
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_start=18848
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLE']._serialized_end=19022
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_start=19025
  _globals['_UNPINNEDREFNEWVERSIONAVAILABLEMSG']._serialized_end=19157
  _globals['_DEPRECATEDMODEL']._serialized_start=19159
  _globals['_DEPRECATEDMODEL']._serialized_end=19245
  _globals['_DEPRECATEDMODELMSG']._serialized_start=19247
  _globals['_DEPRECATEDMODELMSG']._serialized_end=19349
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_start=19352
  _globals['_UPCOMINGREFERENCEDEPRECATION']._serialized_end=19550
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_start=19553
  _globals['_UPCOMINGREFERENCEDEPRECATIONMSG']._serialized_end=19681
  _globals['_DEPRECATEDREFERENCE']._serialized_start=19684
  _globals['_DEPRECATEDREFERENCE']._serialized_end=19873
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_start=19875
  _globals['_DEPRECATEDREFERENCEMSG']._serialized_end=19985
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_start=19987
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATION']._serialized_end=20047
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_start=20050
  _globals['_UNSUPPORTEDCONSTRAINTMATERIALIZATIONMSG']._serialized_end=20194
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_start=20196
  _globals['_GITSPARSECHECKOUTSUBDIRECTORY']._serialized_end=20243
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_start=20246
  _globals['_GITSPARSECHECKOUTSUBDIRECTORYMSG']._serialized_end=20376
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_start=20378
  _globals['_GITPROGRESSCHECKOUTREVISION']._serialized_end=20425
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_start=20427
  _globals['_GITPROGRESSCHECKOUTREVISIONMSG']._serialized_end=20553
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_start=20555
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCY']._serialized_end=20607
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_start=20610
  _globals['_GITPROGRESSUPDATINGEXISTINGDEPENDENCYMSG']._serialized_end=20756
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_start=20758
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCY']._serialized_end=20804
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_start=20807
  _globals['_GITPROGRESSPULLINGNEWDEPENDENCYMSG']._serialized_end=20941
  _globals['_GITNOTHINGTODO']._serialized_start=20943
  _globals['_GITNOTHINGTODO']._serialized_end=20972
  _globals['_GITNOTHINGTODOMSG']._serialized_start=20974
  _globals['_GITNOTHINGTODOMSG']._serialized_end=21074
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_start=21076
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGE']._serialized_end=21145
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_start=21148
  _globals['_GITPROGRESSUPDATEDCHECKOUTRANGEMSG']._serialized_end=21282
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_start=21284
  _globals['_GITPROGRESSCHECKEDOUTAT']._serialized_end=21326
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_start=21328
  _globals['_GITPROGRESSCHECKEDOUTATMSG']._serialized_end=21446
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_start=21448
  _globals['_REGISTRYPROGRESSGETREQUEST']._serialized_end=21489
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_start=21491
  _globals['_REGISTRYPROGRESSGETREQUESTMSG']._serialized_end=21615
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_start=21617
  _globals['_REGISTRYPROGRESSGETRESPONSE']._serialized_end=21678
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_start=21680
  _globals['_REGISTRYPROGRESSGETRESPONSEMSG']._serialized_end=21806
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_start=21808
  _globals['_SELECTORREPORTINVALIDSELECTOR']._serialized_end=21903
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_start=21906
  _globals['_SELECTORREPORTINVALIDSELECTORMSG']._serialized_end=22036
  _globals['_DEPSNOPACKAGESFOUND']._serialized_start=22038
  _globals['_DEPSNOPACKAGESFOUND']._serialized_end=22059
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_start=22061
  _globals['_DEPSNOPACKAGESFOUNDMSG']._serialized_end=22171
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_start=22173
  _globals['_DEPSSTARTPACKAGEINSTALL']._serialized_end=22220
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_start=22222
  _globals['_DEPSSTARTPACKAGEINSTALLMSG']._serialized_end=22340
  _globals['_DEPSINSTALLINFO']._serialized_start=22342
  _globals['_DEPSINSTALLINFO']._serialized_end=22381
  _globals['_DEPSINSTALLINFOMSG']._serialized_start=22383
  _globals['_DEPSINSTALLINFOMSG']._serialized_end=22485
  _globals['_DEPSUPDATEAVAILABLE']._serialized_start=22487
  _globals['_DEPSUPDATEAVAILABLE']._serialized_end=22532
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_start=22534
  _globals['_DEPSUPDATEAVAILABLEMSG']._serialized_end=22644
  _globals['_DEPSUPTODATE']._serialized_start=22646
  _globals['_DEPSUPTODATE']._serialized_end=22660
  _globals['_DEPSUPTODATEMSG']._serialized_start=22662
  _globals['_DEPSUPTODATEMSG']._serialized_end=22758
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_start=22760
  _globals['_DEPSLISTSUBDIRECTORY']._serialized_end=22804
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_start=22806
  _globals['_DEPSLISTSUBDIRECTORYMSG']._serialized_end=22918
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_start=22920
  _globals['_DEPSNOTIFYUPDATESAVAILABLE']._serialized_end=22966
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_start=22968
  _globals['_DEPSNOTIFYUPDATESAVAILABLEMSG']._serialized_end=23092
  _globals['_RETRYEXTERNALCALL']._serialized_start=23094
  _globals['_RETRYEXTERNALCALL']._serialized_end=23143
  _globals['_RETRYEXTERNALCALLMSG']._serialized_start=23145
  _globals['_RETRYEXTERNALCALLMSG']._serialized_end=23251
  _globals['_RECORDRETRYEXCEPTION']._serialized_start=23253
  _globals['_RECORDRETRYEXCEPTION']._serialized_end=23288
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_start=23290
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_end=23402
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_start=23404
  _globals['_REGISTRYINDEXPROGRESSGETREQUEST']._serialized_end=23450
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_start=23453
  _globals['_REGISTRYINDEXPROGRESSGETREQUESTMSG']._serialized_end=23587
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_start=23589
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSE']._serialized_end=23655
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_start=23658
  _globals['_REGISTRYINDEXPROGRESSGETRESPONSEMSG']._serialized_end=23794
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_start=23796
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPE']._serialized_end=23846
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_start=23849
  _globals['_REGISTRYRESPONSEUNEXPECTEDTYPEMSG']._serialized_end=23981
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_start=23983
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYS']._serialized_end=24033
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_start=24036
  _globals['_REGISTRYRESPONSEMISSINGTOPKEYSMSG']._serialized_end=24168
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_start=24170
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYS']._serialized_end=24223
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_start=24226
  _globals['_REGISTRYRESPONSEMISSINGNESTEDKEYSMSG']._serialized_end=24364
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_start=24366
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYS']._serialized_end=24417
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_start=24420
  _globals['_REGISTRYRESPONSEEXTRANESTEDKEYSMSG']._serialized_end=24554
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_start=24556
  _globals['_DEPSSETDOWNLOADDIRECTORY']._serialized_end=24596
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_start=24598
  _globals['_DEPSSETDOWNLOADDIRECTORYMSG']._serialized_end=24718
  _globals['_DEPSUNPINNED']._serialized_start=24720
  _globals['_DEPSUNPINNED']._serialized_end=24765
  _globals['_DEPSUNPINNEDMSG']._serialized_start=24767
  _globals['_DEPSUNPINNEDMSG']._serialized_end=24863
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_start=24865
  _globals['_NONODESFORSELECTIONCRITERIA']._serialized_end=24912
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_start=24914
  _globals['_NONODESFORSELECTIONCRITERIAMSG']._serialized_end=25040
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_start=25042
  _globals['_RUNNINGOPERATIONCAUGHTERROR']._serialized_end=25084
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_start=25086
  _globals['_RUNNINGOPERATIONCAUGHTERRORMSG']._serialized_end=25212
  _globals['_COMPILECOMPLETE']._serialized_start=25214
  _globals['_COMPILECOMPLETE']._serialized_end=25231
  _globals['_COMPILECOMPLETEMSG']._serialized_start=25233
  _globals['_COMPILECOMPLETEMSG']._serialized_end=25335
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_start=25337
  _globals['_FRESHNESSCHECKCOMPLETE']._serialized_end=25361
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_start=25363
  _globals['_FRESHNESSCHECKCOMPLETEMSG']._serialized_end=25479
  _globals['_SEEDHEADER']._serialized_start=25481
  _globals['_SEEDHEADER']._serialized_end=25509
  _globals['_SEEDHEADERMSG']._serialized_start=25511
  _globals['_SEEDHEADERMSG']._serialized_end=25603
  _globals['_SQLRUNNEREXCEPTION']._serialized_start=25605
  _globals['_SQLRUNNEREXCEPTION']._serialized_end=25656
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_start=25658
  _globals['_SQLRUNNEREXCEPTIONMSG']._serialized_end=25766
  _globals['_LOGTESTRESULT']._serialized_start=25769
  _globals['_LOGTESTRESULT']._serialized_end=25937
  _globals['_LOGTESTRESULTMSG']._serialized_start=25939
  _globals['_LOGTESTRESULTMSG']._serialized_end=26037
  _globals['_LOGSTARTLINE']._serialized_start=26039
  _globals['_LOGSTARTLINE']._serialized_end=26146
  _globals['_LOGSTARTLINEMSG']._serialized_start=26148
  _globals['_LOGSTARTLINEMSG']._serialized_end=26244
  _globals['_LOGMODELRESULT']._serialized_start=26247
  _globals['_LOGMODELRESULT']._serialized_end=26396
  _globals['_LOGMODELRESULTMSG']._serialized_start=26398
  _globals['_LOGMODELRESULTMSG']._serialized_end=26498
  _globals['_LOGSNAPSHOTRESULT']._serialized_start=26501
  _globals['_LOGSNAPSHOTRESULT']._serialized_end=26751
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_start=26709
  _globals['_LOGSNAPSHOTRESULT_CFGENTRY']._serialized_end=26751
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_start=26753
  _globals['_LOGSNAPSHOTRESULTMSG']._serialized_end=26859
  _globals['_LOGSEEDRESULT']._serialized_start=26862
  _globals['_LOGSEEDRESULT']._serialized_end=27047
  _globals['_LOGSEEDRESULTMSG']._serialized_start=27049
  _globals['_LOGSEEDRESULTMSG']._serialized_end=27147
  _globals['_LOGFRESHNESSRESULT']._serialized_start=27150
  _globals['_LOGFRESHNESSRESULT']._serialized_end=27323
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_start=27325
  _globals['_LOGFRESHNESSRESULTMSG']._serialized_end=27433
  _globals['_LOGCANCELLINE']._serialized_start=27435
  _globals['_LOGCANCELLINE']._serialized_end=27469
  _globals['_LOGCANCELLINEMSG']._serialized_start=27471
  _globals['_LOGCANCELLINEMSG']._serialized_end=27569
  _globals['_DEFAULTSELECTOR']._serialized_start=27571
  _globals['_DEFAULTSELECTOR']._serialized_end=27602
  _globals['_DEFAULTSELECTORMSG']._serialized_start=27604
  _globals['_DEFAULTSELECTORMSG']._serialized_end=27706
  _globals['_NODESTART']._serialized_start=27708
  _globals['_NODESTART']._serialized_end=27761
  _globals['_NODESTARTMSG']._serialized_start=27763
  _globals['_NODESTARTMSG']._serialized_end=27853
  _globals['_NODEFINISHED']._serialized_start=27855
  _globals['_NODEFINISHED']._serialized_end=27958
  _globals['_NODEFINISHEDMSG']._serialized_start=27960
  _globals['_NODEFINISHEDMSG']._serialized_end=28056
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_start=28058
  _globals['_QUERYCANCELATIONUNSUPPORTED']._serialized_end=28101
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_start=28103
  _globals['_QUERYCANCELATIONUNSUPPORTEDMSG']._serialized_end=28229
  _globals['_CONCURRENCYLINE']._serialized_start=28231
  _globals['_CONCURRENCYLINE']._serialized_end=28310
  _globals['_CONCURRENCYLINEMSG']._serialized_start=28312
  _globals['_CONCURRENCYLINEMSG']._serialized_end=28414
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_start=28416
  _globals['_WRITINGINJECTEDSQLFORNODE']._serialized_end=28485
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_start=28487
  _globals['_WRITINGINJECTEDSQLFORNODEMSG']._serialized_end=28609
  _globals['_NODECOMPILING']._serialized_start=28611
  _globals['_NODECOMPILING']._serialized_end=28668
  _globals['_NODECOMPILINGMSG']._serialized_start=28670
  _globals['_NODECOMPILINGMSG']._serialized_end=28768
  _globals['_NODEEXECUTING']._serialized_start=28770
  _globals['_NODEEXECUTING']._serialized_end=28827
  _globals['_NODEEXECUTINGMSG']._serialized_start=28829
  _globals['_NODEEXECUTINGMSG']._serialized_end=28927
  _globals['_LOGHOOKSTARTLINE']._serialized_start=28929
  _globals['_LOGHOOKSTARTLINE']._serialized_end=29038
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_start=29040
  _globals['_LOGHOOKSTARTLINEMSG']._serialized_end=29144
  _globals['_LOGHOOKENDLINE']._serialized_start=29147
  _globals['_LOGHOOKENDLINE']._serialized_end=29294
  _globals['_LOGHOOKENDLINEMSG']._serialized_start=29296
  _globals['_LOGHOOKENDLINEMSG']._serialized_end=29396
  _globals['_SKIPPINGDETAILS']._serialized_start=29399
  _globals['_SKIPPINGDETAILS']._serialized_end=29546
  _globals['_SKIPPINGDETAILSMSG']._serialized_start=29548
  _globals['_SKIPPINGDETAILSMSG']._serialized_end=29650
  _globals['_NOTHINGTODO']._serialized_start=29652
  _globals['_NOTHINGTODO']._serialized_end=29665
  _globals['_NOTHINGTODOMSG']._serialized_start=29667
  _globals['_NOTHINGTODOMSG']._serialized_end=29761
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_start=29763
  _globals['_RUNNINGOPERATIONUNCAUGHTERROR']._serialized_end=29807
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_start=29810
  _globals['_RUNNINGOPERATIONUNCAUGHTERRORMSG']._serialized_end=29940
  _globals['_ENDRUNRESULT']._serialized_start=29943
  _globals['_ENDRUNRESULT']._serialized_end=30090
  _globals['_ENDRUNRESULTMSG']._serialized_start=30092
  _globals['_ENDRUNRESULTMSG']._serialized_end=30188
  _globals['_NONODESSELECTED']._serialized_start=30190
  _globals['_NONODESSELECTED']._serialized_end=30207
  _globals['_NONODESSELECTEDMSG']._serialized_start=30209
  _globals['_NONODESSELECTEDMSG']._serialized_end=30311
  _globals['_COMMANDCOMPLETED']._serialized_start=30313
  _globals['_COMMANDCOMPLETED']._serialized_end=30432
  _globals['_COMMANDCOMPLETEDMSG']._serialized_start=30434
  _globals['_COMMANDCOMPLETEDMSG']._serialized_end=30538
  _globals['_SHOWNODE']._serialized_start=30540
  _globals['_SHOWNODE']._serialized_end=30647
  _globals['_SHOWNODEMSG']._serialized_start=30649
  _globals['_SHOWNODEMSG']._serialized_end=30737
  _globals['_COMPILEDNODE']._serialized_start=30739
  _globals['_COMPILEDNODE']._serialized_end=30851
  _globals['_COMPILEDNODEMSG']._serialized_start=30853
  _globals['_COMPILEDNODEMSG']._serialized_end=30949
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_start=30951
  _globals['_CATCHABLEEXCEPTIONONRUN']._serialized_end=31049
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_start=31051
  _globals['_CATCHABLEEXCEPTIONONRUNMSG']._serialized_end=31169
  _globals['_INTERNALERRORONRUN']._serialized_start=31171
  _globals['_INTERNALERRORONRUN']._serialized_end=31224
  _globals['_INTERNALERRORONRUNMSG']._serialized_start=31226
  _globals['_INTERNALERRORONRUNMSG']._serialized_end=31334
  _globals['_GENERICEXCEPTIONONRUN']._serialized_start=31336
  _globals['_GENERICEXCEPTIONONRUN']._serialized_end=31411
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_start=31413
  _globals['_GENERICEXCEPTIONONRUNMSG']._serialized_end=31527
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_start=31529
  _globals['_NODECONNECTIONRELEASEERROR']._serialized_end=31607
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_start=31609
  _globals['_NODECONNECTIONRELEASEERRORMSG']._serialized_end=31733
  _globals['_FOUNDSTATS']._serialized_start=31735
  _globals['_FOUNDSTATS']._serialized_end=31766
  _globals['_FOUNDSTATSMSG']._serialized_start=31768
  _globals['_FOUNDSTATSMSG']._serialized_end=31860
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_start=31862
  _globals['_MAINKEYBOARDINTERRUPT']._serialized_end=31885
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_start=31887
  _globals['_MAINKEYBOARDINTERRUPTMSG']._serialized_end=32001
  _globals['_MAINENCOUNTEREDERROR']._serialized_start=32003
  _globals['_MAINENCOUNTEREDERROR']._serialized_end=32038
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_start=32040
  _globals['_MAINENCOUNTEREDERRORMSG']._serialized_end=32152
  _globals['_MAINSTACKTRACE']._serialized_start=32154
  _globals['_MAINSTACKTRACE']._serialized_end=32191
  _globals['_MAINSTACKTRACEMSG']._serialized_start=32193
  _globals['_MAINSTACKTRACEMSG']._serialized_end=32293
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_start=32295
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_end=32359
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_start=32361
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_end=32471
  _globals['_SYSTEMEXECUTINGCMD']._serialized_start=32473
  _globals['_SYSTEMEXECUTINGCMD']._serialized_end=32506
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_start=32508
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_end=32616
  _globals['_SYSTEMSTDOUT']._serialized_start=32618
  _globals['_SYSTEMSTDOUT']._serialized_end=32646
  _globals['_SYSTEMSTDOUTMSG']._serialized_start=32648
  _globals['_SYSTEMSTDOUTMSG']._serialized_end=32744
  _globals['_SYSTEMSTDERR']._serialized_start=32746
  _globals['_SYSTEMSTDERR']._serialized_end=32774
  _globals['_SYSTEMSTDERRMSG']._serialized_start=32776
  _globals['_SYSTEMSTDERRMSG']._serialized_end=32872
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_start=32874
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_end=32918
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_start=32920
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_end=33036
  _globals['_TIMINGINFOCOLLECTED']._serialized_start=33038
  _globals['_TIMINGINFOCOLLECTED']._serialized_end=33150
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_start=33152
  _globals['_TIMINGINFOCOLLECTEDMSG']._serialized_end=33262
  _globals['_LOGDEBUGSTACKTRACE']._serialized_start=33264
  _globals['_LOGDEBUGSTACKTRACE']._serialized_end=33302
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_start=33304
  _globals['_LOGDEBUGSTACKTRACEMSG']._serialized_end=33412
  _globals['_CHECKCLEANPATH']._serialized_start=33414
  _globals['_CHECKCLEANPATH']._serialized_end=33444
  _globals['_CHECKCLEANPATHMSG']._serialized_start=33446
  _globals['_CHECKCLEANPATHMSG']._serialized_end=33546
  _globals['_CONFIRMCLEANPATH']._serialized_start=33548
  _globals['_CONFIRMCLEANPATH']._serialized_end=33580
  _globals['_CONFIRMCLEANPATHMSG']._serialized_start=33582
  _globals['_CONFIRMCLEANPATHMSG']._serialized_end=33686
  _globals['_PROTECTEDCLEANPATH']._serialized_start=33688
  _globals['_PROTECTEDCLEANPATH']._serialized_end=33722
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_start=33724
  _globals['_PROTECTEDCLEANPATHMSG']._serialized_end=33832
  _globals['_FINISHEDCLEANPATHS']._serialized_start=33834
  _globals['_FINISHEDCLEANPATHS']._serialized_end=33854
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_start=33856
  _globals['_FINISHEDCLEANPATHSMSG']._serialized_end=33964
  _globals['_OPENCOMMAND']._serialized_start=33966
  _globals['_OPENCOMMAND']._serialized_end=34019
  _globals['_OPENCOMMANDMSG']._serialized_start=34021
  _globals['_OPENCOMMANDMSG']._serialized_end=34115
  _globals['_FORMATTING']._serialized_start=34117
  _globals['_FORMATTING']._serialized_end=34142
  _globals['_FORMATTINGMSG']._serialized_start=34144
  _globals['_FORMATTINGMSG']._serialized_end=34236
  _globals['_SERVINGDOCSPORT']._serialized_start=34238
  _globals['_SERVINGDOCSPORT']._serialized_end=34286
  _globals['_SERVINGDOCSPORTMSG']._serialized_start=34288
  _globals['_SERVINGDOCSPORTMSG']._serialized_end=34390
  _globals['_SERVINGDOCSACCESSINFO']._serialized_start=34392
  _globals['_SERVINGDOCSACCESSINFO']._serialized_end=34429
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_start=34431
  _globals['_SERVINGDOCSACCESSINFOMSG']._serialized_end=34545
  _globals['_SERVINGDOCSEXITINFO']._serialized_start=34547
  _globals['_SERVINGDOCSEXITINFO']._serialized_end=34568
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_start=34570
  _globals['_SERVINGDOCSEXITINFOMSG']._serialized_end=34680
  _globals['_RUNRESULTWARNING']._serialized_start=34682
  _globals['_RUNRESULTWARNING']._serialized_end=34756
  _globals['_RUNRESULTWARNINGMSG']._serialized_start=34758
  _globals['_RUNRESULTWARNINGMSG']._serialized_end=34862
  _globals['_RUNRESULTFAILURE']._serialized_start=34864
  _globals['_RUNRESULTFAILURE']._serialized_end=34938
  _globals['_RUNRESULTFAILUREMSG']._serialized_start=34940
  _globals['_RUNRESULTFAILUREMSG']._serialized_end=35044
  _globals['_STATSLINE']._serialized_start=35046
  _globals['_STATSLINE']._serialized_end=35153
  _globals['_STATSLINE_STATSENTRY']._serialized_start=35109
  _globals['_STATSLINE_STATSENTRY']._serialized_end=35153
  _globals['_STATSLINEMSG']._serialized_start=35155
  _globals['_STATSLINEMSG']._serialized_end=35245
  _globals['_RUNRESULTERROR']._serialized_start=35247
  _globals['_RUNRESULTERROR']._serialized_end=35276
  _globals['_RUNRESULTERRORMSG']._serialized_start=35278
  _globals['_RUNRESULTERRORMSG']._serialized_end=35378
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_start=35380
  _globals['_RUNRESULTERRORNOMESSAGE']._serialized_end=35421
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_start=35423
  _globals['_RUNRESULTERRORNOMESSAGEMSG']._serialized_end=35541
  _globals['_SQLCOMPILEDPATH']._serialized_start=35543
  _globals['_SQLCOMPILEDPATH']._serialized_end=35574
  _globals['_SQLCOMPILEDPATHMSG']._serialized_start=35576
  _globals['_SQLCOMPILEDPATHMSG']._serialized_end=35678
  _globals['_CHECKNODETESTFAILURE']._serialized_start=35680
  _globals['_CHECKNODETESTFAILURE']._serialized_end=35725
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_start=35727
  _globals['_CHECKNODETESTFAILUREMSG']._serialized_end=35839
  _globals['_FIRSTRUNRESULTERROR']._serialized_start=35841
  _globals['_FIRSTRUNRESULTERROR']._serialized_end=35875
  _globals['_FIRSTRUNRESULTERRORMSG']._serialized_start=35877
  _globals['_FIRSTRUNRESULTERRORMSG']._serialized_end=35987
  _globals['_AFTERFIRSTRUNRESULTERROR']._serialized_start=35989
  _globals['_AFTERFIRSTRUNRESULTERROR']._serialized_end=36028
  _globals['_AFTERFIRSTRUNRESULTERRORMSG']._serialized_start=36030
  _globals['_AFTERFIRSTRUNRESULTERRORMSG']._serialized_end=36150
  _globals['_ENDOFRUNSUMMARY']._serialized_start=36152
  _globals['_ENDOFRUNSUMMARY']._serialized_end=36239
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_start=36241
  _globals['_ENDOFRUNSUMMARYMSG']._serialized_end=36343
  _globals['_LOGSKIPBECAUSEERROR']._serialized_start=36345
  _globals['_LOGSKIPBECAUSEERROR']._serialized_end=36430
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_start=36432
  _globals['_LOGSKIPBECAUSEERRORMSG']._serialized_end=36542
  _globals['_ENSUREGITINSTALLED']._serialized_start=36544
  _globals['_ENSUREGITINSTALLED']._serialized_end=36564
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_start=36566
  _globals['_ENSUREGITINSTALLEDMSG']._serialized_end=36674
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_start=36676
  _globals['_DEPSCREATINGLOCALSYMLINK']._serialized_end=36702
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_start=36704
  _globals['_DEPSCREATINGLOCALSYMLINKMSG']._serialized_end=36824
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_start=36826
  _globals['_DEPSSYMLINKNOTAVAILABLE']._serialized_end=36851
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_start=36853
  _globals['_DEPSSYMLINKNOTAVAILABLEMSG']._serialized_end=36971
  _globals['_DISABLETRACKING']._serialized_start=36973
  _globals['_DISABLETRACKING']._serialized_end=36990
  _globals['_DISABLETRACKINGMSG']._serialized_start=36992
  _globals['_DISABLETRACKINGMSG']._serialized_end=37094
  _globals['_SENDINGEVENT']._serialized_start=37096
  _globals['_SENDINGEVENT']._serialized_end=37126
  _globals['_SENDINGEVENTMSG']._serialized_start=37128
  _globals['_SENDINGEVENTMSG']._serialized_end=37224
  _globals['_SENDEVENTFAILURE']._serialized_start=37226
  _globals['_SENDEVENTFAILURE']._serialized_end=37244
  _globals['_SENDEVENTFAILUREMSG']._serialized_start=37246
  _globals['_SENDEVENTFAILUREMSG']._serialized_end=37350
  _globals['_FLUSHEVENTS']._serialized_start=37352
  _globals['_FLUSHEVENTS']._serialized_end=37365
  _globals['_FLUSHEVENTSMSG']._serialized_start=37367
  _globals['_FLUSHEVENTSMSG']._serialized_end=37461
  _globals['_FLUSHEVENTSFAILURE']._serialized_start=37463
  _globals['_FLUSHEVENTSFAILURE']._serialized_end=37483
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_start=37485
  _globals['_FLUSHEVENTSFAILUREMSG']._serialized_end=37593
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_start=37595
  _globals['_TRACKINGINITIALIZEFAILURE']._serialized_end=37640
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_start=37642
  _globals['_TRACKINGINITIALIZEFAILUREMSG']._serialized_end=37764
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_start=37766
  _globals['_RUNRESULTWARNINGMESSAGE']._serialized_end=37804
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_start=37806
  _globals['_RUNRESULTWARNINGMESSAGEMSG']._serialized_end=37924
  _globals['_DEBUGCMDOUT']._serialized_start=37926
  _globals['_DEBUGCMDOUT']._serialized_end=37952
  _globals['_DEBUGCMDOUTMSG']._serialized_start=37954
  _globals['_DEBUGCMDOUTMSG']._serialized_end=38048
  _globals['_DEBUGCMDRESULT']._serialized_start=38050
  _globals['_DEBUGCMDRESULT']._serialized_end=38079
  _globals['_DEBUGCMDRESULTMSG']._serialized_start=38081
  _globals['_DEBUGCMDRESULTMSG']._serialized_end=38181
  _globals['_LISTCMDOUT']._serialized_start=38183
  _globals['_LISTCMDOUT']._serialized_end=38208
  _globals['_LISTCMDOUTMSG']._serialized_start=38210
  _globals['_LISTCMDOUTMSG']._serialized_end=38302
  _globals['_NOTE']._serialized_start=38304
  _globals['_NOTE']._serialized_end=38323
  _globals['_NOTEMSG']._serialized_start=38325
  _globals['_NOTEMSG']._serialized_end=38405
# @@protoc_insertion_point(module_scope)
